@@ -12,13 +12,13 @@ BEGIN {
     use vars        qw[ @ISA $VERSION @EXPORT_OK $VERBOSE $ALLOW_UNKNOWN
                         $STRICT_TYPE $STRIP_LEADING_DASHES $NO_DUPLICATES
                         $PRESERVE_CASE $ONLY_ALLOW_DEFINED $WARNINGS_FATAL
-                        $SANITY_CHECK_TEMPLATE
+                        $SANITY_CHECK_TEMPLATE $CALLER_DEPTH $_ERROR_STRING
                     ];
 
     @ISA        =   qw[ Exporter ];
     @EXPORT_OK  =   qw[check allow last_error];
 
-    $VERSION = "-1";
+    $VERSION                = '0.26';
     $VERBOSE                = $^W ? 1 : 0;
     $NO_DUPLICATES          = 0;
     $STRIP_LEADING_DASHES   = 0;
@@ -28,6 +28,7 @@ BEGIN {
     $ONLY_ALLOW_DEFINED     = 0;
     $SANITY_CHECK_TEMPLATE  = 1;
     $WARNINGS_FATAL         = 0;
+    $CALLER_DEPTH           = 0;
 }
 
 my %known_keys = map { $_ => 1 }
@@ -38,7 +39,7 @@ my %known_keys = map { $_ => 1 }
 
 =head1 NAME
 
-Params::Check -- A generic input parsing/checking mechanism.
+Params::Check - A generic input parsing/checking mechanism.
 
 =head1 SYNOPSIS
 
@@ -334,8 +335,10 @@ sub check {
 
         ### check if we have an allow handler, to validate against ###
         ### allow() will report its own errors ###
-        if( exists $tmpl{'allow'} and
-            not allow($args{$key}, $tmpl{'allow'})
+        if( exists $tmpl{'allow'} and not do {
+                local $_ERROR_STRING;
+                allow( $args{$key}, $tmpl{'allow'} )
+            }         
         ) {
             ### stringify the value in the error report -- we don't want dumps
             ### of objects, but we do want to see *roughly* what we passed
@@ -534,7 +537,7 @@ sub _safe_eq {
 sub _who_was_it {
     my $level = $_[0] || 0;
 
-    return (caller(2 + $level))[3] || 'ANON'
+    return (caller(2 + $CALLER_DEPTH + $level))[3] || 'ANON'
 }
 
 =head2 last_error()
@@ -549,7 +552,7 @@ It is exported upon request.
 
 =cut
 
-{   my $ErrorString = '';
+{   $_ERROR_STRING = '';
 
     sub _store_error {
         my($err, $verbose, $offset) = @_[0..2];
@@ -561,14 +564,14 @@ It is exported upon request.
 
         carp $err if $verbose;
 
-        $ErrorString .= $err . "\n";
+        $_ERROR_STRING .= $err . "\n";
     }
 
     sub _clear_error {
-        $ErrorString = '';
+        $_ERROR_STRING = '';
     }
 
-    sub last_error { $ErrorString }
+    sub last_error { $_ERROR_STRING }
 }
 
 1;
@@ -656,24 +659,47 @@ template validation occurs, rather than return C<false>.
 
 Default is 0;
 
-=head1 AUTHOR
+=head2 $Params::Check::CALLER_DEPTH
 
-This module by
-Jos Boumans E<lt>kane@cpan.orgE<gt>.
+This global modifies the argument given to C<caller()> by
+C<Params::Check::check()> and is useful if you have a custom wrapper
+function around C<Params::Check::check()>. The value must be an
+integer, indicating the number of wrapper functions inserted between
+the real function call and C<Params::Check::check()>.
+
+Example wrapper function, using a custom stacktrace:
+
+    sub check {
+        my ($template, $args_in) = @_;
+
+        local $Params::Check::WARNINGS_FATAL = 1;
+        local $Params::Check::CALLER_DEPTH = $Params::Check::CALLER_DEPTH + 1;
+        my $args_out = Params::Check::check($template, $args_in);
+
+        my_stacktrace(Params::Check::last_error) unless $args_out;
+
+        return $args_out;
+    }
+
+Default is 0;
 
 =head1 Acknowledgements
 
 Thanks to Richard Soderberg for his performance improvements.
 
+=head1 BUG REPORTS
+
+Please report bugs or other issues to E<lt>bug-params-check@rt.cpan.orgE<gt>.
+
+=head1 AUTHOR
+
+This module by Jos Boumans E<lt>kane@cpan.orgE<gt>.
+
 =head1 COPYRIGHT
 
-This module is
-copyright (c) 2003,2004 Jos Boumans E<lt>kane@cpan.orgE<gt>.
-All rights reserved.
+This library is free software; you may redistribute and/or modify it 
+under the same terms as Perl itself.
 
-This library is free software;
-you may redistribute and/or modify it under the same
-terms as Perl itself.
 
 =cut
 
