@@ -207,6 +207,8 @@ use constant CHECKSUMS      => 'CHECKSUMS';
 use constant PGP_HEADER     => '-----BEGIN PGP SIGNED MESSAGE-----';
 use constant ENV_CPANPLUS_CONFIG
                             => 'PERL5_CPANPLUS_CONFIG';
+use constant ENV_CPANPLUS_IS_EXECUTING
+                            => 'PERL5_CPANPLUS_IS_EXECUTING';
 use constant DEFAULT_EMAIL  => 'cpanplus@example.com';   
 use constant CPANPLUS_UA    => sub { ### for the version number ###
                                      require CPANPLUS::Internals;
@@ -242,7 +244,6 @@ use constant CALLING_FUNCTION
                             => sub { my $lvl = $_[0] || 0;
                                      return join '::', (caller(2+$lvl))[3] 
                                 };
-use constant DOT_EXISTS     => '.exists';     
 use constant PERL_CORE      => 'perl';
 
 use constant GET_XS_FILES   => sub { my $dir = $_[0] or return;
@@ -259,6 +260,7 @@ use constant GET_XS_FILES   => sub { my $dir = $_[0] or return;
 use constant INSTALL_LOG_FILE 
                             => sub { my $obj  = shift or return;
                                      my $name = $obj->name; $name =~ s/::/-/g;
+                                     $name .= '-'. $obj->version;
                                      $name .= '-'. scalar(time) . '.log';
                                      return $name;
                                 };                                        
@@ -269,12 +271,16 @@ use constant ON_CYGWIN      => $^O eq 'cygwin';
 use constant ON_VMS         => $^O eq 'VMS';
 
 use constant ON_OLD_CYGWIN  => do { ON_CYGWIN and $] < 5.008 
-                                    ? loc("Your perl version for %1 is too low; ".
-                                            "Require %2 or higher for this function",
-                                            $^O, '5.8.0' )
+                                    ? loc(
+                                       "Your perl version for %1 is too low; ".
+                                       "Require %2 or higher for this function",
+                                       $^O, '5.8.0' )
                                     : '';                                                                           
                                 };
 
+### XXX these 2 are probably obsolete -- check & remove;
+use constant DOT_EXISTS     => '.exists'; 
+
 use constant QUOTE_PERL_ONE_LINER 
                             => sub { my $line = shift or return;
 
