@@ -1,7 +1,7 @@
 package CPANPLUS::Internals::Report;
 
 use strict;
-use CPANPLUS::inc;
+
 use CPANPLUS::Error;
 use CPANPLUS::Internals::Constants;
 use CPANPLUS::Internals::Constants::Report;
@@ -17,13 +17,35 @@ $Params::Check::VERBOSE = 1;
 ### for the version ###
 require CPANPLUS::Internals;
 
-=head2 _have_query_report_modules
+=head1 NAME
+
+CPANPLUS::Internals::Report
+
+=head1 SYNOPSIS
+
+  ### enable test reporting
+  $cb->configure_object->set_conf( cpantest => 1 );
+    
+  ### set custom mx host, shouldn't normally be needed
+  $cb->configure_object->set_conf( cpantest_mx => 'smtp.example.com' );
+
+=head1 DESCRIPTION
+
+This module provides all the functionality to send test reports to
+C<http://testers.cpan.org> using the C<Test::Reporter> module.
+
+All methods will be called automatically if you have C<CPANPLUS>
+configured to enable test reporting (see the C<SYNOPSIS>).
+
+=head1 METHODS
+
+=head2 $bool = $cb->_have_query_report_modules
 
 This function checks if all the required modules are here for querying
 reports. It returns true and loads them if they are, or returns false
 otherwise.
 
-=head2 _have_send_report_modules
+=head2 $bool = $cb->_have_send_report_modules
 
 This function checks if all the required modules are here for sending
 reports. It returns true and loads them if they are, or returns false
@@ -76,7 +98,7 @@ otherwise.
     }
 }
 
-=head2 _query_report( module => $modobj, [all_versions => BOOL, verbose => BOOL] )
+=head2 @list = $cb->_query_report( module => $modobj, [all_versions => BOOL, verbose => BOOL] )
 
 This function queries the CPAN testers database at
 I<http://testers.cpan.org/> for test results of specified module objects,
@@ -180,7 +202,7 @@ sub _query_report {
 
 =pod
 
-=head2 _send_report( module => $modobj, buffer => $make_output, failed => BOOL, [save => BOOL, address => $email_to, dontcc => BOOL, verbose => BOOL, force => BOOL]);
+=head2 $bool = $cb->_send_report( module => $modobj, buffer => $make_output, failed => BOOL, [save => BOOL, address => $email_to, dontcc => BOOL, verbose => BOOL, force => BOOL]);
 
 This function sends a testers report to C<cpan-testers@perl.org> for a
 particular distribution.
@@ -285,6 +307,7 @@ sub _send_report {
     my $email   = $mod->author->email || CPAN_MAIL_ACCOUNT->( $author );
     my $cp_conf = $conf->get_conf('cpantest') || '';
     my $int_ver = $CPANPLUS::Internals::VERSION;
+    my $cb      = $mod->parent;
 
 
     ### determine the grade now ###
@@ -293,7 +316,44 @@ sub _send_report {
     ### check if this is a platform specific module ###
     ### if we failed the test, there may be reasons why 
     ### an 'NA' might have to be insted
-    if ( $failed ) {
+    GRADE: { if ( $failed ) {
+        
+
+        ### XXX duplicated logic between this block
+        ### and REPORTED_LOADED_PREREQS :(
+        
+        ### figure out if the prereqs are on CPAN at all
+        ### -- if not, send NA grade
+        ### Also, if our version of prereqs is too low,
+        ### -- send NA grade.
+        ### This is to address bug: #25327: do not count 
+        ### as FAIL modules where prereqs are not filled
+        {   my $prq = $mod->status->prereqs || {};
+        
+            while( my($prq_name,$prq_ver) = each %$prq ) {
+                my $obj = $cb->module_tree( $prq_name );
+                
+                unless( $obj ) {
+                    msg(loc( "Prerequisite '%1' for '%2' could not be obtained".
+                             " from CPAN -- sending N/A grade", 
+                             $prq_name, $name ), $verbose );
+
+                    $grade = GRADE_NA;
+                    last GRADE;        
+                }
+
+                if( $cb->_vcmp( $prq_ver, $obj->installed_version ) > 0 ) {
+                    msg(loc( "Installed version of '%1' ('%2') is too low for ".
+                             "'%3' (needs '%4') -- sending N/A grade", 
+                             $prq_name, $obj->installed_version, 
+                             $name, $prq_ver ), $verbose );
+                             
+                    $grade = GRADE_NA;
+                    last GRADE;        
+                }                             
+            }
+        }
+        
         unless( RELEVANT_TEST_RESULT->($mod) ) {
             msg(loc(
                 "'%1' is a platform specific module, and the test results on".
@@ -331,7 +391,7 @@ sub _send_report {
     ### is in order
     } else {
         $grade = GRADE_PASS;
-    }
+    } }
 
     ### so an error occurred, let's see what stage it went wrong in ###
     my $message;
@@ -425,7 +485,12 @@ sub _send_report {
                         grade           => $grade,
                         distribution    => $dist,
                         via             => "CPANPLUS $int_ver",
+                        debug           => $conf->get_conf('debug'),
                     );
+                    
+    ### set a custom mx, if requested
+    $reporter->mx( [ $conf->get_conf('cpantest_mx') ] ) 
+        if $conf->get_conf('cpantest_mx');
 
     ### set the from address ###
     $reporter->from( $conf->get_conf('email') )
