@@ -26,7 +26,7 @@ local $Data::Dumper::Indent     = 1; # for dumpering from !
 BEGIN {
     use vars        qw[ $VERSION @ISA ];
     @ISA        =   qw[ CPANPLUS::Shell::_Base::ReadLine ];
-    $VERSION = "0.076";
+    $VERSION = "0.78";
 }
 
 load CPANPLUS::Shell;
@@ -82,13 +82,13 @@ CPANPLUS::Shell::Default
     $ perl -MCPANPLUS -eshell   # load the shell from the command line
 
 
-    use CPANPLUS::Shell qw[Default];    # load this shell via the API
-                                        # always done via CPANPLUS::Shell
+    use CPANPLUS::Shell qw[Default];        # load this shell via the API
+                                            # always done via CPANPLUS::Shell
 
     my $ui = CPANPLUS::Shell->new;
-    $ui->shell;                         # run the shell
-    $ui->dispatch_on_input('x');        # update the source using the
-                                        # dispatch method
+    $ui->shell;                             # run the shell
+    $ui->dispatch_on_input( input => 'x');  # update the source using the
+                                            # dispatch method
 
     ### when in the shell:
     ### Note that all commands can also take options.
@@ -125,6 +125,7 @@ CPANPLUS::Shell::Default
     cpanp> s program         # show program settings
     cpanp> s edit            # edit config file
     cpanp> s reconfigure     # go through initial configuration again
+    cpanp> s selfupdate      # update your CPANPLUS install
     cpanp> s save            # save config to disk
     cpanp> s mirrors         # show currently selected mirrors
 
@@ -143,6 +144,10 @@ CPANPLUS::Shell::Default
     cpanp> /plugins          # list avialable plugins
     cpanp> /? PLUGIN         # list help test of <PLUGIN>                  
 
+    ### common options:
+    cpanp> i ... --skiptest # skip tests
+    cpanp> i ... --force    # force all operations
+    cpanp> i ... --verbose  # run in verbose mode
 
 =head1 DESCRIPTION
 
@@ -156,11 +161,12 @@ sub new {
 
     my $cb      = new CPANPLUS::Backend;
     my $self    = $class->SUPER::_init(
-                            brand   => $Brand,
-                            term    => Term::ReadLine->new( $Brand ),
-                            prompt  => $Prompt,
-                            backend => $cb,
-                            format  => "%5s %-50s %8s %-10s\n",
+                            brand       => $Brand,
+                            term        => Term::ReadLine->new( $Brand ),
+                            prompt      => $Prompt,
+                            backend     => $cb,
+                            format      => "%4s %-55s %8s %-10s\n",
+                            dist_format => "%4s %-42s %-12s %8s %-10s\n",
                         );
     ### make it available package wide ###
     $Shell = $self;
@@ -203,8 +209,11 @@ sub new {
 sub shell {
     my $self = shift;
     my $term = $self->term;
+    my $conf = $self->backend->configure_object;
 
     $self->_show_banner;
+    print "*** Type 'p' now to show start up log\n"; # XXX add to banner?
+    $self->_show_random_tip if $conf->get_conf('show_startup_tip');
     $self->_input_loop && print "\n";
     $self->_quit;
 }
@@ -268,11 +277,22 @@ sub dispatch_on_input {
             { $input =~ s|^\s*([!?/])|$1 |; }
 
             ### get the first letter of the input
-            $input =~ s|^\s*([\w\?\!/])\w*\s*||;
+            $input =~ s|^\s*([\w\?\!/])\w*||;
 
             chomp $input;
             $key =  lc($1);
 
+            ### we figured out what the command was...
+            ### if we have more input, that DOES NOT start with a white
+            ### space char, we misparsed.. like 'Test::Foo::Bar', which
+            ### would turn into 't', '::Foo::Bar'...
+            if( $input and $input !~ s/^\s+// ) {
+                print loc("Could not understand command: %1\n".
+                          "Possibly missing command before argument(s)?\n",
+                          $org_input); 
+                return;
+            }     
+
             ### allow overrides from the config file ###
             if( defined $rc->{$key} ) {
                 $input = $rc->{$key} . $input;
@@ -401,7 +421,7 @@ sub _format_version {
     $version = 0 if $version eq 'undef';
     $version =~ s/_//g; # everything after gets stripped off otherwise
 
-    ### allow 6 digits after the dot, as that's who perl stringifies
+    ### allow 6 digits after the dot, as that's how perl stringifies
     ### x.y.z numbers.
     $version = sprintf('%3.6f', $version);
     $version = '' if $version == '0.00';
@@ -425,11 +445,22 @@ sub __display_results {
             next unless $mod;   # first one is undef
                                 # humans start counting at 1
 
-            printf $self->format,
+            ### for dists only -- we have checksum info
+            if( $mod->mtime ) {
+                printf $self->dist_format,
+                            $i,
+                            $mod->module,
+                            $mod->mtime,
+                            $self->_format_version($mod->version),
+                            $mod->author->cpanid();
+
+            } else {
+                printf $self->format,
                             $i,
                             $mod->module,
                             $self->_format_version($mod->version),
                             $mod->author->cpanid();
+            }
             $i++;
         }
 
@@ -499,6 +530,7 @@ loc('    s program [OPT VALUE]  # set program locations for this session'
 loc('    s conf    [OPT VALUE]  # set config options for this session'              ),
 loc('    s mirrors              # show currently selected mirrors' ),
 loc('    s reconfigure          # reconfigure settings ' ),
+loc('    s selfupdate           # update your CPANPLUS install '),
 loc('    s save [user|system]   # save settings for this user or systemwide' ),
 loc('    s edit [user|system]   # open configuration file in editor and reload'     ),
 loc('    ! EXPR                 # evaluate a perl statement'                        ),
@@ -1038,7 +1070,7 @@ sub _set_conf {
 
     ### possible options
     ### XXX hard coded, not optimal :(
-    my @types   = qw[reconfigure save edit program conf mirrors];
+    my @types   = qw[reconfigure save edit program conf mirrors selfupdate];
 
 
     my $args; my $opts; my $input;
@@ -1112,8 +1144,24 @@ sub _set_conf {
             $i++;
             print "\t[$i] $uri\n";
         }
-        
 
+    } elsif ( $type eq 'selfupdate' ) {
+        my %valid = map { $_ => $_ } 
+                        qw|core dependencies enabled_features features all|;
+
+        unless( $valid{$key} ) {
+            print loc( "To update your current CPANPLUS installation, ".
+                        "choose one of the these options:\n%1",
+                        (join $/, map {"\ts selfupdate $_"} sort keys %valid) );          
+        } else {
+            print loc( "Updating your CPANPLUS installation\n" );
+            $cb->selfupdate_object->selfupdate( 
+                                    update  => $key, 
+                                    latest  => 1,
+                                    %$opts 
+                                );
+        }
+        
     } else {
 
         if ( $type eq 'program' or $type eq 'conf' ) {
@@ -1377,6 +1425,7 @@ sub _reports {
 ### Load plugins
 {   my @PluginModules;
     my %Dispatch = ( 
+        showtip => [ __PACKAGE__, '_show_random_tip'], 
         plugins => [ __PACKAGE__, '_list_plugins'   ], 
         '?'     => [ __PACKAGE__, '_plugins_usage'  ],
     );        
@@ -1494,6 +1543,11 @@ sub _reports {
         return sprintf $help_format, 'plugins', loc("lists available plugins");
     }
 
+    ### registered as a plugin too
+    sub _show_random_tip_help {
+        return sprintf $help_format, 'showtip', loc("show usage tips" );
+    }   
+
     sub _plugins_usage {
         my $pkg     = shift;
         my $shell   = shift;
@@ -1578,26 +1632,51 @@ sub _read_configuration_from_rc {
     return $href || {};
 }
 
+{   my @tips = (
+        loc( "You can update CPANPLUS by running: '%1'", 's selfupdate' ),
+        loc( "You can install modules by URL using '%1'", 'i URL' ),
+        loc( "You can turn off these tips using '%1'", 
+             's conf show_startup_tip 0' ),
+        loc( "You can use wildcards like '%1' and '%2' on search results",
+             '*', '..' ),
+        loc( "You can use plugins. Type '%1' to list available plugins",
+             '/plugins' ),
+        loc( "You can show all your out of date modules using '%1'", 'o' ),  
+        loc( "Many operations take options, like '%1' or '%2'",
+             '--verbose', '--skiptest' ),
+        loc( "The documentation in %1 and %2 is very useful",
+             "CPANPLUS::Module", "CPANPLUS::Backend" ),
+        loc( "You can type '%1' for help and '%2' to exit", 'h', 'q' ),
+    );
+    
+    sub _show_random_tip {
+        my $self = shift;
+        print $/, "Did you know...\n    ", $tips[ int rand scalar @tips ], $/;
+        return 1;
+    }
+}    
+
 1;
 
 __END__
 
 =pod
 
+=head1 BUG REPORTS
+
+Please report bugs or other issues to E<lt>bug-cpanplus@rt.cpan.org<gt>.
+
 =head1 AUTHOR
 
-This module by
-Jos Boumans E<lt>kane@cpan.orgE<gt>.
+This module by Jos Boumans E<lt>kane@cpan.orgE<gt>.
 
 =head1 COPYRIGHT
 
-The CPAN++ interface (of which this module is a part of) is
-copyright (c) 2001, 2002, 2003, 2004, Jos Boumans E<lt>kane@cpan.orgE<gt>.
-All rights reserved.
+The CPAN++ interface (of which this module is a part of) is copyright (c) 
+2001 - 2007, Jos Boumans E<lt>kane@cpan.orgE<gt>. All rights reserved.
 
-This library is free software;
-you may redistribute and/or modify it under the same
-terms as Perl itself.
+This library is free software; you may redistribute and/or modify it 
+under the same terms as Perl itself.
 
 =head1 SEE ALSO
 
